require(pomp)

#######################################################################################################
# Load Covars & Data
#######################################################################################################
covariates2 <- read.csv('Thai_Covariates_short2.csv', header=TRUE);
covariates1 <- covariates2[,-c(1)]
covariates <- covariates1 
covariates$modelID <- param.sets$model[1];
covariates$boosting <- param.sets$boost[1];

covariates$seas <- periodic.bspline.basis(covariates$timevec,nbasis=6,degree=2,period=1);
covariates$seasB <- periodic.bspline.basis(covariates$timevec,nbasis=6,degree=2,period=1);

# covariates$modelID <- param.sets$model[1:109];
# covariates$boosting <- param.sets$boost[1:109];
#######################################################################################################
# Functions we need to transform params
#######################################################################################################
expit=function(x){1.0/(1.0+exp(-x))};
logit=function(p){log(p/(1-p))};

#######################################################################################################
# Set up data frame with the data to be fit, this dataframe should start at timestep==1
#######################################################################################################
CASES1 <- read.csv('Thai_CPOX_SHING_short.csv', header=TRUE);   #DO NOT PAD DATA
CASES <- CASES1[1:96,]
#######################################################################################################
# Compile/load model from C-code
#######################################################################################################
if (is.loaded("zoster_meas_dens")) dyn.unload("VZV_new.so")
system("R CMD SHLIB VZV_new.c")
dyn.load("VZV_new.so")

#######################################################################################################
# POMP Object
#######################################################################################################
my.model1<- pomp(
      data=CASES[c("step","POX","SHING")], # data are cases and associated timestep, starting w/ timestep==1
      times="step", # name of time variable in data dataframe
      rprocess=euler.sim("zoster_proc_sim",delta.t=1/4,PACKAGE="VZV_new"), # polio_proc_sim is the name of our process model in C-code; measles_biweekly is the name of our C file; see ?plugins for integration options
      rmeasure="zoster_meas_sim", # name of measurement model in C-code
      dmeasure="zoster_meas_dens", # name of measurement density model in C-code
      PACKAGE="VZV_new", # name of C-file
      t0=0, # time 0, this is the time we initialize the model
      obsnames=c("POX","SHING"), # name of observations in data dataframe
      statenames=c("pS","pE","pI","pL1","pL2","FOI","S","E","IVZ","L1","IHZ","L2",'IVZNEW','IHZNEW','rep_hz'), # process model state variable names, this vector must match the order of the states in (x[stateindex[i]]) in C-code
      covarnames=c("population","births","coc1","coc2","UV","UV2","TT","modelID","boosting","seas.1","seasB.1"), # covariate names, must match order of (covar[covindex[i]]) in C-code
      paramnames=c('delta','Neta','zeta1','Omega','Alpha','Beta_SD','Phi','Gamma','Iota','rhovz','tauvz','tauhz','m1','m2','zeta1B','eta','omicron','chi','upsilon','sigma','a','nu','xi','mult','expony'), # param names, must match order of (p[parindex[0]]) in C-code, but notice the actual name doesn't have to match for instance here we use "alpha" in C-code we call it LOGALPHA, only the indexing matters not the exact name
      tcovar="step", # name of the time variable in the covariate data frame
      covar=covariates, # name of the covariate dataframe
      initializer=function(params,t0, ...){ # the initializer allows you to specify how to set up initial conditions using your parameter set "params"
            p <- expit(params)
            covars<- as.data.frame(covariates)
            with(
              as.list(p),
              {
                x0=c(pS.0,pE.0,pI.0,pL1.0,pL2.0,FOI.0,S.0,E.0,IVZ.0,L1.0,IHZ.0,L2.0,IVZNEW.0,IHZNEW.0,rep_hz.0)   #this are the initial states
                x0[1:6]= 0;
                IC_sum=sum(x0[7:12]);
                x0[7]= round((x0[7]/IC_sum)*covars[109,'population']); #S                       
                x0[8]= round((x0[8]/IC_sum)*covars[109,'population']); #E
                x0[9]= round((x0[9]/IC_sum)*covars[109,'population']); #IVZ
                x0[10]= round((x0[10]/IC_sum)*covars[109,'population']); #L1
                x0[11]= round((x0[11]/IC_sum)*covars[109,'population']); #IHZ
                x0[12]= round((x0[12]/IC_sum)*covars[109,'population']); #L2
                x0[13:14]= 0; #IVZNEW, IHZNEW
                # x0[15]= x0[15]; #it stays as it is
                names(x0)=c("pS","pE","pI","pL1","pL2","FOI","S","E","IVZ","L1","IHZ","L2","IVZNEW","IHZNEW","rep_hz");
                x0
            }
          )
    }
)
#######################################################################################################
# end pomp object
#######################################################################################################